package cn.timer.api.controller.zpgl;

import cn.timer.api.aspect.lang.annotation.Log;
import cn.timer.api.aspect.lang.enums.BusinessType;
import cn.timer.api.bean.zpgl.*;
import cn.timer.api.dto.zpgl.InterviewApplicationDto;
import cn.timer.api.utils.Result;
import cn.timer.api.utils.ResultUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.BeanUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.transaction.Transactional;
import java.util.List;

@Api(tags = "招聘管理")
@Transactional(rollbackOn = Exception.class)
@RestController
@RequestMapping(value = "/zpgl/h5")
public class ZpglH5Controller {

    /**
     * 添加面试申请
     * @param
     * @return
     */
    @RequestMapping("/add_interview_application")
    @ApiOperation(value = "添加面试申请", httpMethod = "POST", notes = "添加面试申请")
    @Log(title = "addInterviewApplication", businessType = BusinessType.INSERT_UPDATE)
    public Result<Object> addInterviewApplication(@Validated @RequestBody InterviewApplicationDto interviewApplicationDto) {
        System.out.println(interviewApplicationDto);
        ZpglRcxx zpglRcxx = new ZpglRcxx();
        //复制到 ZpglRcxx 实体对象
        BeanUtils.copyProperties(interviewApplicationDto,zpglRcxx);
        zpglRcxx.insertOrUpdate();

        //添加紧急联系人
        if(interviewApplicationDto.getZpglRcxxLxxxb() != null){
            ZpglRcxxLxxxb zpglRcxxLxxxb = interviewApplicationDto.getZpglRcxxLxxxb();
            zpglRcxxLxxxb.setZpglRcxxId(zpglRcxx.getId());
            zpglRcxxLxxxb.insertOrUpdate();
        }

        //新增/修改工作经验
        if(interviewApplicationDto.getZpglRcxxExperience().size()>0){
            List<ZpglRcxxExperience> experiences = interviewApplicationDto.getZpglRcxxExperience();
            for(ZpglRcxxExperience experience : experiences){
                if(experience.getCompany() != null){
                    experience.setZpglRcxxId(zpglRcxx.getId());
                    experience.insertOrUpdate();
                }
            }
        }

        //新增/修改教育经历
        if(interviewApplicationDto.getZpglRcxxStudy().size()>0){
            List<ZpglRcxxStudy> zpglRcxxStudys = interviewApplicationDto.getZpglRcxxStudy();
            for(ZpglRcxxStudy study : zpglRcxxStudys){
                if(study.getSchoolName() != null){
                    study.setZpglRcxxId(zpglRcxx.getId());
                    study.insertOrUpdate();
                }
            }
        }
        //新增/修改家庭资料
        if(interviewApplicationDto.getZpglRcxxJtzls().size()>0){
            List<ZpglRcxxJtzl> zpglRcxxJtzls = interviewApplicationDto.getZpglRcxxJtzls();
            for(ZpglRcxxJtzl jtzl : zpglRcxxJtzls){
                if(jtzl.getName() != null){
                    jtzl.setZpglRcxxId(zpglRcxx.getId());
                    jtzl.insertOrUpdate();
                }
            }
        }


        return ResultUtil.success();
    }

    /**
     * 查询面试申请信息
     * @param
     * @return
     */
    @RequestMapping("/interview_application_info/{mobile}")
    @ApiOperation(value = "查询面试申请信息", httpMethod = "GET", notes = "查询面试申请信息")
    @Log(title = "interviewApplicationIofo", businessType = BusinessType.INSERT_UPDATE)
    public Result<InterviewApplicationDto> interviewApplicationIofo(@PathVariable String mobile) {
        System.out.println(mobile);
        if(mobile == null || "".equals(mobile)){
            return ResultUtil.error("手机号不能为空");
        }
        InterviewApplicationDto dto = new InterviewApplicationDto();
        List<ZpglRcxx> zpglRcxxes = ZpglRcxx.builder().build()
                .selectList(new QueryWrapper<ZpglRcxx>().lambda()
                        .eq(ZpglRcxx::getMobile, mobile));
        if(zpglRcxxes.size() == 0){
            return ResultUtil.error("没有简历信息");
        }

        ZpglRcxx zpglRcxx = zpglRcxxes.get(0);
        //复制到dto
        BeanUtils.copyProperties(zpglRcxx,dto);

        //联系人信息
        List<ZpglRcxxLxxxb> zpglRcxxLxxxbs = ZpglRcxxLxxxb.builder().build().selectList(new QueryWrapper<ZpglRcxxLxxxb>()
                .lambda().select(ZpglRcxxLxxxb::getId,ZpglRcxxLxxxb::getLinkName,ZpglRcxxLxxxb::getLinkMobile)
                .eq(ZpglRcxxLxxxb::getZpglRcxxId, zpglRcxx.getId()));
        dto.setZpglRcxxLxxxb(zpglRcxxLxxxbs.get(0));

        //工作经验
        List<ZpglRcxxExperience> experiences = ZpglRcxxExperience.builder().build()
                .selectList(new QueryWrapper<ZpglRcxxExperience>()
                .lambda().eq(ZpglRcxxExperience::getZpglRcxxId, zpglRcxx.getId()));
        dto.setZpglRcxxExperience(experiences);

        //教育经历
        List<ZpglRcxxStudy> study = ZpglRcxxStudy.builder().build()
                .selectList(new QueryWrapper<ZpglRcxxStudy>()
                        .lambda().eq(ZpglRcxxStudy::getZpglRcxxId, zpglRcxx.getId()));
        dto.setZpglRcxxStudy(study);

        //家庭资料
        List<ZpglRcxxJtzl> jtzl = ZpglRcxxJtzl.builder().build()
                .selectList(new QueryWrapper<ZpglRcxxJtzl>()
                        .lambda().eq(ZpglRcxxJtzl::getZpglRcxxId, zpglRcxx.getId()));
        dto.setZpglRcxxJtzls(jtzl);

        return ResultUtil.data(dto,"查询成功");
    }
}
